netapp_ontap.models.file_move_scanner API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.file_move_scanner`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FileMoveScannerSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FileMoveScanner object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `percent: Size GET`

    Scanner progress, as a percentage.

    Example: 80

  `progress: Size GET`

    Scanner progress, in bytes scanned.

    Example: 80000

  `state: str GET`

    Status of the file move scanner.

    Valid choices:

    - allocation_map
    - complete
    - data
    - destroyed
    - destroying
    - paused_admin
    - paused_error
    - preparing
  `total: Size GET`

    Total bytes to be scanned.

    Example: 100000